#!/bin/sh
# Here is a script that can be used to trigger data recording from an alert. 
# The script will activate a persistence collection named "All Alert Conditions" 
# and record all its metrics either to the database or flat file, depending 
# on the configuration. The script will turn off data recording after 10 minutes.  

#
# Determine automatically where our home is.
# resolve links - $0 may be a softlink
PRG="$0"
while [ -h "$PRG" ] ; do
  ls=`ls -ld "$PRG"`
  link=`expr "$ls" : '.*-> \(.*\)$'`
  if expr "$link" : '.*/.*' > /dev/null; then
    PRG="$link"
  else
    PRG=`dirname "$PRG"`/"$link"
  fi
done
PRGDIR=`dirname "$PRG"`

# Set environment
if [ -f $PRGDIR/setIscEnv.sh ] ; then
	. $PRGDIR/setIscEnv.sh
else
	echo "There is no environment setup file: setIscEnv.sh"
	echo "Please re-run configureWily in installation directory!"
	exit
fi

SEMAPHORE=$ISC_LOGS/tmp/alertLevelLogging.tmp
# Logging Info
LOG_FILE=$ISC_LOGS/alertReporting.log
ERR_FILE=$ISC_LOGS/alertReporting.err

# Recording Period (e.g. 10 min ) in secs
REPORTING_PERIOD=600
# Set to next hour beyond the minutes above
# for comparison of semaphore file
NEXT_HOUR_BEYOND=1

# Define matching persistent collections
COLLECTIONS="All Alert Conditions"
# Define matching modules
MODULES="(.*)"


# Java Options (e.g. increase Max heap size )
JAVA_OPTS="-Xms64m -Xmx512m"
JAVA_OPTS="$JAVA_OPTS $USER_OPT $PASSWORD_OPT $EM_HOST_OPT $EM_PORT_OPT"

echo `date` : Alert message: $1 >> $LOG_FILE

# Would use %s but not supported on all UNIX
#TIME_STR=`date +%s`
TIME_STR=`date +%Y%m%d%H`

if [ -f "$SEMAPHORE" ]; then
	TIME_STR_OLD=`cat $SEMAPHORE`
	# Check that semaphore is not just a lingerer (rare case)
	TIME_DIFF=`expr $TIME_STR - $TIME_STR_OLD`
	# Do conservative check for greater than 1 hour
	if [ $TIME_DIFF -le $NEXT_HOUR_BEYOND ] ; then
		echo `date` : Already running alert level logging >> $LOG_FILE
		exit
	fi
fi
echo $TIME_STR > $SEMAPHORE
echo `date` : Enabling alert level logging >> $LOG_FILE
$ISC_JAVA_HOME/bin/java $JAVA_OPTS -jar $CLW_JAR \
	enable persistent collections matching \"$COLLECTIONS\" in \
	management modules matching \"$MODULES\" >> $LOG_FILE 2>> $ERR_FILE
sleep $REPORTING_PERIOD
echo `date` : Disabling alert level logging >> $LOG_FILE
$ISC_JAVA_HOME/bin/java $JAVA_OPTS -jar $CLW_JAR \
	disable persistent collections matching \"$COLLECTIONS\" in \
	management modules matching \"$MODULES\" >> $LOG_FILE 2>> $ERR_FILE
rm $SEMAPHORE
