#!/bin/sh

#
# Determine automatically where our home is.
# resolve links - $0 may be a softlink
PRG="$0"
while [ -h "$PRG" ] ; do
  ls=`ls -ld "$PRG"`
  link=`expr "$ls" : '.*-> \(.*\)$'`
  if expr "$link" : '.*/.*' > /dev/null; then
    PRG="$link"
  else
    PRG=`dirname "$PRG"`/"$link"
  fi
done
PRGDIR=`dirname "$PRG"`

# Set environment
if [ -f $PRGDIR/setIscEnv.sh ] ; then
	. $PRGDIR/setIscEnv.sh
else
	echo "There is no environment setup file: setIscEnv.sh"
	echo "Please re-run configureWily in installation directory!"
	exit
fi

TT_THRESHOLD_IN_MSECS=$1
TT_DURATION_IN_SECS=$2
if [ $# -lt 2 ] ; then
	echo "Syntax: clwTxnTracer <threshold> <duration>"
	exit 1
elif [ $TT_THRESHOLD_IN_MSECS -le 0 ]; then
	echo "Threshold less than zero: $TT_THRESHOLD_IN_MSECS"
	exit
elif [ $TT_DURATION_IN_SECS -le 0 ]; then
	echo "Duration less than zero: $TT_DURATION_IN_SECS"
	exit
fi
TT_AGENTS="(.*)"

# Java Options (e.g. increase Max heap size )
JAVA_OPTS="-Xms64m -Xmx512m"
JAVA_OPTS="$JAVA_OPTS $USER_OPT $PASSWORD_OPT $EM_HOST_OPT $EM_PORT_OPT"

COMMAND="trace transactions exceeding $TT_THRESHOLD_IN_MSECS milliseconds in agents matching \"$TT_AGENTS\" for $TT_DURATION_IN_SECS seconds"

YR_STRING=`date +%Y`
YR_DIR=$ISC_TRACES/$YR_STRING
if [ ! -d $YR_DIR ] ; then
	echo Making output directory: $YR_DIR
	mkdir $YR_DIR
fi
MONTH_STRING=`date +%m`
MONTH_DIR=$YR_DIR/$MONTH_STRING
if [ ! -d $MONTH_DIR ] ; then
	echo Making output directory: $MONTH_DIR
	mkdir $MONTH_DIR
fi
DAY_STRING=`date +%d`
DAY_DIR=$MONTH_DIR/$DAY_STRING
if [ ! -d $DAY_DIR ] ; then
	echo Making output directory: $DAY_DIR
	mkdir $DAY_DIR
fi
AGENT_STR=$TT_AGENTS
# Remove the spaces, parentheses
AGENT_STR=`echo $AGENT_STR|sed -e 's/[ ()]//g'`
if [ "X$TT_AGENTS" = "X(.*)" ] ; then
	AGENT_STR="AllAgents"
fi
SECS_STR=`date +%s`
TT_FILE="${DAY_DIR}/${AGENT_STR}_${TT_THRESHOLD_IN_MSECS}msecs_for${TT_DURATION_IN_SECS}secs.${SECS_STR}.xml"

# send stderr to null b/c there are meaningless disconnect excepts that might be *scary-looking*
$ISC_JAVA_HOME/bin/java $JAVA_OPTS -jar $CLW_JAR $COMMAND > $TT_FILE 2>/dev/null
